/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {

dojo.provide("com.ibm.rational.report.web.core.client.internal.ProcessClient");

dojo.require("com.ibm.rational.report.web.core.client.internal.SessionManager");
dojo.require("com.ibm.rational.report.web.core.app.internal.common.ErrorDialog");
dojo.require("com.ibm.team.repository.web.transport.ServiceRequest");
dojo.require("com.ibm.team.repository.web.transport.ServiceResponseHandler");
dojo.require("com.ibm.team.repository.web.transport.TeamServerClient");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.serviceability", "Messages");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.internal", "Messages");

var SessionManager			= com.ibm.rational.report.web.core.client.internal.SessionManager;
var ServiceRequest 			= com.ibm.team.repository.web.transport.ServiceRequest;
var ServiceResponseHandler 	= com.ibm.team.repository.web.transport.ServiceResponseHandler;
var TeamServerClient 		= com.ibm.team.repository.web.transport.TeamServerClient;
var ServiceabilityMessages	= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.serviceability", "Messages");
var InternalMessages 		= com.ibm.rational.report.web.core.app.internal;

/**
 * Manages process REST service calls.
 */
com.ibm.rational.report.web.core.client.internal.ProcessClient = {

	SERVICE_URI: "com.ibm.team.process.internal.common.service.IProcessRestService",
	
	//getTeamAreasForUser is not available in IProcessRestService any more after beta2
	//so please get the process areas from here, and get all children recursivly from each project area
	//please refer to the IProcessRestService for details
	//or check implementation in UploadReportDesign.js as a reference
	getProcessAreasForUser: function(responseHandler, args) {
		if (!args.userId) {		
			var errorReason = dojo.string.substitute(InternalMessages.MISSING_REQUIRED_PARAMETERS,
				["ProcessClient#getProcessAreasForUser", args.userId]);
			var errorMsg = dojo.string.substitute(ServiceabilityMessages.INTERNAL_APPLICATION_ERROR_WITH_REASON,
				[errorReason]);
			this._displayErrorMessage(errorMsg);
			return;
		}
		this._invokeProcessService(responseHandler, "getProcessAreasForUser", args);
	},
	
	/**
	 * Invokes the requested method on the Process REST service.
	 */
	_invokeProcessService: function(responseHandler, method, args) {
		var serviceRequest = new ServiceRequest(this.SERVICE_URI, method, args);
		TeamServerClient.invokeService(serviceRequest, responseHandler);
		SessionManager.resetTimeOut();
	},
	
	_displayErrorMessage: function(errorMsg) {
		var errorDialog = new com.ibm.rational.report.web.core.app.internal.common.ErrorDialog();
		errorDialog.displayError(errorMsg);
	}
	
};

})();